@@ -8,27 +8,28 @@ from src.autodiffpypi.base_derivatives import *
 from src.autodiffpypi.dual_number import *
 
 class Forward():
-    def __init__(self, fn, num_of_inputs):
+    def __init__(self, function_list, num_of_inputs):
         """ Initialize Forward mode class
 
         Params:
             self: Forward
-            fn: array, function
+            function_list: array, function
             num_of_inputs: int
         """
-        if isinstance(fn, list):
-            if len(fn) == 0:
+        if isinstance(function_list, list):
+            if len(function_list) == 0:
                 raise ValueError("Input to Forward class should be a function or a non-empty list of functions")
-            for elt in fn:
+            for elt in function_list:
                 if not callable(elt):
                     raise ValueError("Input to Forward class should be a function or a non-empty list of functions")
-            self.fn = np.array(fn)
-        elif callable(fn):
-            self.fn = np.array([fn])
+            self.function_list = np.array(function_list)
+        elif callable(function_list):
+            self.function_list = np.array([function_list])
         else:
             raise ValueError("Input to Forward class should be a function or a non-empty list of functions")
         if not isinstance(num_of_inputs, int):
             raise TypeError("Input to Forward class num_of_inputs should be an int")
+        
         self.num_of_inputs = num_of_inputs
 
 
@@ -63,11 +64,19 @@ class Forward():
         duals = [DualNumber(input) for input in inputs]
 
         # Multiple functions
-        if len(self.fn) > 1:
-            return np.array([np.array([fun(*duals).real]) for fun in self.fn])
+        if len(self.function_list) > 1:
+            res = []
+            for fun in self.function_list:
+                fun_params = len(signature(fun).parameters)
+                if len(duals) > fun_params:
+                    # Address edge case where not all functions take the same number of inputs
+                    res.append(np.array([fun(*duals[0:fun_params]).real]))
+                else:
+                    res.append(np.array([fun(*duals).real]))
+            return np.array(res)
         # Single function
         else:
-            return self.fn[0](*duals).real
+            return self.function_list[0](*duals).real
 
 
     def derivative(self, inputs, index = None):
@@ -105,7 +114,7 @@ class Forward():
         if len(inputs) == 1 or index is None:
             index = 0
 
-        if len(self.fn) > 1:
+        if len(self.function_list) > 1:
             lst = self.jacobian(inputs)[:, index]
             return np.array([[elt] for elt in lst])
         else:
@@ -148,9 +157,9 @@ class Forward():
         
         # Per function, we want to have a numpy list
         res = []
-        for fun in self.fn:
+        for fun in self.function_list:
             arr = []
-            for ind, duals in enumerate(duals_list):
+            for duals in duals_list:
                 fun_params = len(signature(fun).parameters)
                 if len(duals) > fun_params:
                     arr.append(fun(*duals[0:fun_params]).dual)
