@@ -9,23 +9,22 @@ from src.autodiffpypi.reverse_mode import Reverse
 
 class Mixed_Mode(Forward, Reverse):
 
-    def __init__(self, fn, num_of_inputs, threshold = 50000):
+    def __init__(self, function_list, num_of_inputs, threshold = 50000):
         """ Initialize Mixed mode class
         Params:
             self: Mixed_Mode
-            fn: array, function: ()
+            function_list: array, function: ()
             num_inputs: number of inputs
             threshold: number of inputs at which reverse mode is used instead of forward mode
         """
-        self.fn = fn
+        self.function_list = function_list
         self.num_of_inputs = num_of_inputs
-        # by default this is 3, but user can change it
         self.threshold = threshold
 
         # fewer inputs --> use forward mode
         if(num_of_inputs < threshold):
-            Forward.__init__(self, fn, num_of_inputs)
+            Forward.__init__(self, function_list, num_of_inputs)
 
         # more inputs --> use reverse mode
         else:
-            Reverse.__init__(self, fn, num_of_inputs) 
\ No newline at end of file
+            Reverse.__init__(self, function_list, num_of_inputs) 
\ No newline at end of file
