@@ -3,25 +3,25 @@
 # Description: Computes Reverse-mode AD
 
 import numpy as np
+from inspect import signature
 from src.autodiffpypi.base_derivatives import *
 from src.structures.graph import Node
 
 class Reverse():
 
-    # def __init__(self, fn, nodes):
-    def __init__(self, fn, num_inputs):
+    def __init__(self, function_list, num_of_inputs):
         """ Initialize Reverse mode class
 
         Params:
             self: Reverse
-            fn: array, function: () -> Node
-            num_inputs: number of inputs
+            function_list: array, function
+            num_of_inputs: int, number of inputs
         """
-        self.fn = np.array(fn) if isinstance(fn, list) else np.array([fn])
-        self.num_inputs = num_inputs
+        self.function_list = np.array(function_list) if isinstance(function_list, list) else np.array([function_list])
+        self.num_of_inputs = num_of_inputs
     
     def build_nodes(self, inputs):
-        """ Helper function to build node variables
+        """ Helper function to build nodes from inputs
         Params:
             self: Reverse
             inputs: List of integers
@@ -40,15 +40,12 @@ class Reverse():
         >>> print(value)
         [Node(2), Node(5)]
         """
-        if len(inputs) != self.num_inputs:
+        # type checking
+        if len(inputs) != self.num_of_inputs:
             raise IndexError
 
-        # build nodes out of input variables
-        node_list = []
-        for var in inputs:
-            node_list.append(Node(var))
-        
-        return node_list
+        # build nodes out of input variables        
+        return [Node(var) for var in inputs]
 
     def evaluate(self, inputs):
         """ Evaluate input functions
@@ -71,18 +68,28 @@ class Reverse():
         >>> print(value)
         [32, 7]
         """
-        # build nodes out of input variables
         node_list = self.build_nodes(inputs)
 
-        # evaluate all functions at those variables
-        res_arr = []
-        for func in self.fn:
-            res_arr.append(func(*node_list).value)
+        # Multiple functions
+        if len(self.function_list) > 1:
+            res = []
+            for func in self.function_list:
+                fun_params = len(signature(func).parameters)
+                if len(node_list) > fun_params:
+                    # Address edge case where not all functions take the same number of inputs
+                    res.append(np.array([func(*node_list[0:fun_params]).value]))
+                else:
+                    res.append(np.array([func(*node_list).value]))
+            return np.array(res)
 
-        return res_arr
+        # evaluate all functions at those variables
+        return [func(*node_list).value for func in self.function_list]
 
     def derivative(self, inputs, index = None):
-        """ Compute derivative
+        """ Compute derivative with respect to input at specified index.
+        If not index is specified and the function is only of one variable,
+        it will return the derivative with respect to that variable.
+
         Params:
             self: Reverse
             inputs: List of integers
@@ -103,27 +110,25 @@ class Reverse():
         >>> print(value)
         [32log(2), 1]
         """
+
+        # type checking
         if isinstance(inputs, (float, int)):
             inputs = [inputs]
-
-        if len(inputs) != self.num_inputs:
+        if len(inputs) != self.num_of_inputs:
             raise ValueError("Number of input variables must match function definition")
-
         if index is not None and not isinstance(index, int):
             raise TypeError("Index must be an int")
 
-        # default to derivative of x if no index provided
+        # default to derivative of first variable if no index provided
         if len(inputs) == 1 or index is None:
             index = 0
 
-        # return specified column(s) of jacobian
-        if len(self.fn) > 1:
+        if len(self.function_list) > 1:
             lst = self.jacobian(inputs)[:, index]
             return np.array([[elt] for elt in lst])
         else:
             return self.jacobian(inputs)[0][index]
 
-
     def jacobian(self, inputs):
         """ Compute jacobian matrix of derivatives
         Params:
@@ -144,10 +149,8 @@ class Reverse():
         >>> print(value)
         [ [12, 8log(2)], [1, 1] ]
         """
-        # build nodes out of input variables
         node_list = self.build_nodes(inputs)
 
-        m  = []
-        for func in self.fn:
-            m.append([func(*node_list).get_gradients()[node] for node in node_list])
-        return np.array(m)
+        # build jacobian matrix
+        jac = [[func(*node_list).get_gradients()[node] for node in node_list] for  func in self.function_list]
+        return np.array(jac)
\ No newline at end of file
