@@ -14,13 +14,9 @@ class Node:
         Params:
             self: Node
             value: int or float
-            parent_gradients: array of tuples
-                type: (Node parent_node, int local_gradient)
-                    parent_node is a parent node of self
-                    local_gradient is the derivative of self with respect to parent_node
-            derivate: int or float
-                default: 1
-
+            parent_gradients: array of tuples of type (Node, int / float)
+            name: string
+ 
         """
         if not isinstance(value, (*self._supported_types, Node)):
             raise TypeError(f"Type error: `{type(value)}`")
@@ -33,6 +29,14 @@ class Node:
         return (f"(Node name: {self.name}, value: {self.value}, parent gradients: {self.parent_gradients})")
 
     def __hash__(self):
+        """ Creates the hash value for Node self
+        Params:
+            self: Node
+        
+        Returns:
+            y: hash value for Node self
+        """
+
         return hash((self.value, str(self.parent_gradients), str(self.name)))
 
     def get_gradients(self):
