@@ -54,7 +54,15 @@ def test_forward_mode():
 
         with pytest.raises(ValueError):
             Forward([f1, f2], 2).evaluate(x)
-
+        
+        # Test edge case where there are two fucntions with different number of inputs
+        x = 3
+        y = 2
+        f1 = lambda x, y: x - y
+        f2 = lambda x: x
+        result = Forward([f1, f2], 2).evaluate([x, y])
+        assert(result[0] == 1)
+        assert(result[1] == 3)
 
     def test_derivative():
         x = 2
