@@ -19,7 +19,8 @@ def test_reverse_mode():
         y = -4
 
         reverse_ex = Reverse([f1, f2], 2)
-        assert reverse_ex.evaluate([x, y]) == [-53584980.0, 346]
+        assert reverse_ex.evaluate([x, y])[0] == -53584980.0
+        assert reverse_ex.evaluate([x, y])[1] == 346
         reverse_ex = Reverse([f1], 2)
         assert reverse_ex.evaluate([x, y]) == [-53584980.0]
 
@@ -33,7 +34,17 @@ def test_reverse_mode():
 
         reverse_ex = Reverse([f1, f2], 2)
         value = reverse_ex.evaluate([x, y])
-        assert value == [32, 7]
+        assert value[0] == 32
+        assert value[1] == 7
+
+        # Test edge case where there are two fucntions with different number of inputs
+        x = 3
+        y = 2
+        f1 = lambda x, y: x - y
+        f2 = lambda x: x
+        result = Reverse([f1, f2], 2).evaluate([x, y])
+        assert(result[0] == 1)
+        assert(result[1] == 3)
 
     def test_build_nodes():
         x = 2
@@ -56,7 +67,8 @@ def test_reverse_mode():
         y = -4
 
         reverse_ex = Reverse([f1, f2], 2)
-        assert reverse_ex.evaluate([x, y]) == [-53584980.0, 346]
+        assert reverse_ex.evaluate([x, y])[0] == -53584980.0
+        assert reverse_ex.evaluate([x, y])[1] == 346
 
         with pytest.raises(IndexError):
             reverse_ex.evaluate([x])
